@@ -92,6 +92,12 @@ has '_extra_queue_arg' => (
 	init_arg => undef
 );
 
+has '_cpu_multiplier' => (
+	is       => 'rw',
+	default  => 1,
+	init_arg => undef
+);
+
 for my $l (@_qa) {
 	my ( $k, $p, $s, $sa, $d, $a ) = @$l;
 	$_qaparse{$k}   = $p;
@@ -206,8 +212,9 @@ sub pe_parse {
 	my $ref_extra = shift;
 	my $pe = $self->str1_parse( $key, $ref_extra );
 	my $range = $self->str1_parse( "$key $pe", $ref_extra );
-	$range =~ /(^\d+-?\d*$)|(^-\d*$)/
+	$range =~ /(^(\d+)-?\d*$)|(^-\d*$)/
 		or croak "invalid range arg ($range) found for extra qsub option ($key name($pe))";
+	$self->_cpu_multiplier( $2 ) if defined $2;
 	return "$pe $range";
 }
 
